@@ -1,6 +1,9 @@
 import re
 import json
 import aiohttp
+import asyncio
+import lxml.html
+import urllib.parse
 from datetime import datetime
 
 analysis_stat = {}   # analysis_stat: video_url(vurl)
@@ -17,13 +20,11 @@ async def bili_keyword(group_id, text):
             while i < len(desc):
                 title_dict = "{"+desc[i]+"}"
                 title = eval(title_dict)
-                i += 1
-                if title['desc'] == "哔哩哔哩":
-                    continue
                 vurl = await search_bili_by_title(title['desc'])
                 if vurl:
                     url = await extract(vurl)
                     break
+                i += 1
         
         # 获取视频详细信息
         if "bangumi" in url:
@@ -58,7 +59,7 @@ async def b23_extract(text):
 async def extract(text:str):
     try:
         aid = re.compile(r'av\d+', re.I).search(text)
-        bvid = re.compile(r'BV([a-zA-Z0-9])+', re.I).search(text)
+        bvid = re.compile(r'BV([a-zA-Z0-9]{10})+', re.I).search(text)
         epid = re.compile(r'ep\d+', re.I).search(text)
         ssid = re.compile(r'ss\d+', re.I).search(text)
         mdid = re.compile(r'md\d+', re.I).search(text)
@@ -83,18 +84,24 @@ async def extract(text:str):
         return None
 
 async def search_bili_by_title(title: str):
-    search_url = f'http://api.bilibili.com/x/web-interface/search/all/v2?keyword={title}'
-    print(search_url)
-    async with aiohttp.request('GET', search_url, timeout=aiohttp.client.ClientTimeout(10)) as resp:
-        r = await resp.json()
-    
-    result = r["data"]["result"]
-    for i in result:
-        if i.get("result_type") != "video":
-            continue
-        # 只返回第一个结果
-        url = i["data"][0].get("arcurl")
-        return url
+    brackets_pattern = re.compile(r'[()\[\]{}（）【】]')
+    title_without_brackets = brackets_pattern.sub(' ', title).strip()
+    search_url = f'https://search.bilibili.com/video?keyword={urllib.parse.quote(title_without_brackets)}'
+
+    try:
+        async with aiohttp.request('GET', search_url, timeout=aiohttp.client.ClientTimeout(10)) as resp:
+            text = await resp.text(encoding='utf8')
+            content: lxml.html.HtmlElement = lxml.html.fromstring(text)
+    except asyncio.TimeoutError:
+        return None
+
+    for video in content.xpath('//li[@class="video-item matrix"]/a[@class="img-anchor"]'):
+        if title == ''.join(video.xpath('./attribute::title')):
+            url = ''.join(video.xpath('./attribute::href'))
+            break
+    else:
+        url = None
+    return url
 
 async def video_detail(url):
     try:
@@ -165,20 +172,17 @@ async def live_detail(url):
         if lock_status:
             lock_time = res['data']['room_info']['lock_time']
             lock_time = datetime.fromtimestamp(lock_time).strftime("%Y-%m-%d %H:%M:%S")
-            title = f"[已封禁]直播间封禁至：{lock_time}\n"
+            title = f"(已封禁)直播间封禁至：{lock_time}\n"
         elif live_status == 1:
-            title = f"[直播中]标题：{title}\n"
+            title = f"(直播中)标题：{title}\n"
         elif live_status == 2:
-            title = f"[轮播中]标题：{title}\n"
+            title = f"(轮播中)标题：{title}\n"
         else:
-            title = f"[未开播]标题：{title}\n"
+            title = f"(未开播)标题：{title}\n"
         up = f"主播：{uname} 当前分区：{parent_area_name}-{area_name} 人气上一次刷新值：{online}\n"
         if tags:
             tags = f"标签：{tags}\n"
-        if live_status:
-            player = f"独立播放器：https://www.bilibili.com/blackboard/live/live-activity-player.html?enterTheRoom=0&cid={room_id}"
-        else:
-            player = ""
+        player = f"独立播放器：https://www.bilibili.com/blackboard/live/live-activity-player.html?enterTheRoom=0&cid={room_id}"
         msg = str(vurl)+str(title)+str(up)+str(tags)+str(player)
         return msg, vurl
     except Exception as e:
